Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var DictsLen [numDicts]int
Functions ¶
func NewUsernameGen ¶
func NewUsernameGen() *usernameGen
func NewUsernameGenWithOptions ¶
func NewUsernameGenWithOptions(delimiter string, postfixType PostfixType, dicts ...DictType) *usernameGen
Types ¶
type PostfixType ¶
type PostfixType byte
const ( // Do not use any postfix NoPostfix PostfixType = iota // Use the provided number as postfix for the result in // case the number overflows the total possible values UseProvidedNumberAfterOverflow PostfixType = iota // Use the provided number as postfix for the result UseProvidedNumber PostfixType = iota )
Click to show internal directories.
Click to hide internal directories.